@@ -1,4 +1,5 @@
 """Constants for WMATA API."""
+from enum import Enum
 from zoneinfo import ZoneInfo
 
 BASE_URL = "https://api.wmata.com"
@@ -7,3 +8,9 @@ HEADER_PREFIX = "wmataio"
 CLASS_HEADER = f"{HEADER_PREFIX}-class"
 ENUM_HEADER = f"{HEADER_PREFIX}-enum"
 ADDITIONAL_PATH_HEADER = f"{HEADER_PREFIX}-additional-path"
+
+
+class WMATAEndpoint(Enum):
+    """Generic WMATA Endpoints."""
+
+    VALIDATE_API_KEY = f"{BASE_URL}/Misc/Validate"
